##
##  libmicrohttpd.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         libmicrohttpd
Summary:      Micro HTTP Daemon Library
URL:          http://www.gnu.org/software/libmicrohttpd/
Vendor:       Christian Grothoff, Sagie Amir, Richard Alimi
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      LGPL
Version:      1.0.1
Release:      20240223

#   package options
%option       with_ssl  yes

#   list of sources
Source0:      http://ftp.gnu.org/gnu/libmicrohttpd/libmicrohttpd-%{version}.tar.gz
Patch0:       libmicrohttpd.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, pkgconfig
PreReq:       OpenPKG, openpkg >= 20160101
%if "%{with_ssl}" == "yes"
BuildPreReq:  gcrypt, gnutls
PreReq:       gcrypt, gnutls
%endif

%description
    GNU libmicrohttpd is a small C library that is supposed to make it
    easy to run an HTTP server as part of another application. It has
    an API that is simple, expressive and fully reentrant. It is HTTP
    1.1 compliant, can listen on multiple ports, supports IPv6, supports
    incremental processing of POST data, has three different threading
    models and has optional support for SSL3/TLS.

%track
    prog libmicrohttpd = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/libmicrohttpd/
        regex     = libmicrohttpd-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    export CC="%{l_cc}"
    export CFLAGS="%{l_cflags -O}"
    export CPPFLAGS="%{l_cppflags}"
    export LDFLAGS="%{l_ldflags}"
    export LIBS=""
%if "%{with_ssl}" == "yes"
    CPPFLAGS="$CPPFLAGS `pkg-config gnutls --cflags`"
    LDFLAGS="$LDFLAGS `pkg-config gnutls --libs-only-L`"
    LIBS="$LIBS `pkg-config gnutls --libs-only-l` -liconv"
%endif
    ./configure \
        --prefix=%{l_prefix} \
        --infodir=%{l_prefix}/info \
        --mandir=%{l_prefix}/man \
%if "%{with_ssl}" == "yes"
        --enable-https \
        --with-libgcrypt-prefix=%{l_prefix} \
        --with-gnutls=%{l_prefix} \
%else
        --disable-https \
%endif
        --disable-curl \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

